@@ -41,8 +41,12 @@
 #'   Lists can be arbitrarily nested, as in `list()`.
 #' @param names Subset of `names(values)`
 #'   used to generate the suffixes in the names of the new targets.
-#'   You can supply symbols, a character vector,
-#'   or tidyselect helpers like [starts_with()].
+#'   The value of `names` should be a `tidyselect` expression
+#'   such as a call to [any_of()] or [starts_with()].
+#' @param descriptions Names of a column in `values`
+#'   to append to the custom description of each generated target.
+#'   The value of `descriptions` should be a `tidyselect` expression
+#'   such as a call to [any_of()] or [starts_with()].
 #' @param unlist Logical, whether to flatten the returned list of targets.
 #'   If `unlist = FALSE`, the list is nested and sub-lists
 #'   are named and grouped by the original input targets.
@@ -67,6 +71,7 @@ tar_map <- function(
   values,
   ...,
   names = tidyselect::everything(),
+  descriptions = tidyselect::everything(),
   unlist = FALSE
 ) {
   targets <- unlist(list(...), recursive = TRUE) %|||% list()
@@ -74,10 +79,17 @@ tar_map <- function(
   assert_values_list(values)
   names_quosure <- rlang::enquo(names)
   names <- eval_tidyselect(names_quosure, base::names(values))
+  descriptions_quosure <- rlang::enquo(descriptions)
+  descriptions <- eval_tidyselect(descriptions_quosure, base::names(values))
   values <- tibble::as_tibble(values)
   values <- tar_map_process_values(values)
   values <- tar_map_extend_values(targets, values, names)
-  out <- lapply(targets, tar_map_target, values = values)
+  out <- lapply(
+    X = targets,
+    FUN = tar_map_target,
+    values = values,
+    descriptions = descriptions
+  )
   flat <- unlist(out, recursive = TRUE)
   if_any(
     unlist,
@@ -120,30 +132,30 @@ tar_map_produce_suffix <- function(values, names) {
 }
 
 tar_map_default_suffixes <- function(values) {
-  id <- apply(
-    X = values,
-    MARGIN = 1,
-    FUN = digest::digest,
-    algo = "xxhash32"
-  )
-  list(id = id)
+  list(id = apply(X = values, MARGIN = 1, FUN = hash_object))
 }
 
-tar_map_target <- function(target, values) {
+tar_map_target <- function(target, values, descriptions) {
   lapply(
-    transpose(values),
-    tar_map_iter,
+    X = transpose(values),
+    FUN = tar_map_iter,
     target = target,
     command = target$command$expr,
-    pattern = target$settings$pattern
+    pattern = target$settings$pattern,
+    descriptions = descriptions
   )
 }
 
-tar_map_iter <- function(values, target, command, pattern) {
+tar_map_iter <- function(values, target, command, pattern, descriptions) {
   settings <- target$settings
   name <- as.character(values[[settings$name]])
   command <- substitute_expr(command, values)
   pattern <- substitute_expr(pattern, values) %||% NULL
+  description <- tar_map_extend_description(
+    description = settings$description,
+    values = values,
+    descriptions = descriptions
+  )
   targets::tar_target_raw(
     name = name,
     command = command,
@@ -169,6 +181,16 @@ tar_map_iter <- function(values, target, command, pattern) {
       repository = target$cue$repository,
       iteration = target$cue$iteration,
       file = target$cue$file
-    )
+    ),
+    description = description
   )
 }
+
+tar_map_extend_description <- function(description, values, descriptions) {
+  description <- as.character(description)
+  if (length(descriptions) > 0L) {
+    suffix <- paste(as.character(values[descriptions]), collapse = " ")
+    description <- paste(description, suffix)
+  }
+  trimws(description)
+}
