@@ -42,6 +42,7 @@ tar_map2_raw <- function(
   command2,
   values = NULL,
   names = NULL,
+  descriptions = quote(tidyselect::everything()),
   group = quote(rep(1L, nrow(as.data.frame(!!.x)))),
   combine = TRUE,
   columns1 = quote(tidyselect::everything()),
@@ -62,7 +63,8 @@ tar_map2_raw <- function(
   resources = targets::tar_option_get("resources"),
   storage = targets::tar_option_get("storage"),
   retrieval = targets::tar_option_get("retrieval"),
-  cue = targets::tar_option_get("cue")
+  cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description")
 ) {
   targets::tar_assert_scalar(name)
   targets::tar_assert_chr(name)
@@ -80,6 +82,9 @@ tar_map2_raw <- function(
   if (!is.null(names)) {
     targets::tar_assert_lang(names)
   }
+  if (!is.null(descriptions)) {
+    targets::tar_assert_lang(descriptions)
+  }
   if (!is.null(columns1)) {
     targets::tar_assert_lang(columns1)
   }
@@ -121,7 +126,8 @@ tar_map2_raw <- function(
     resources = resources,
     storage = storage,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
   target_downstream <- targets::tar_target_raw(
     name = name_downstream,
@@ -145,7 +151,8 @@ tar_map2_raw <- function(
     resources = resources,
     storage = storage,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
   target_static <- if_any(
     is.null(values),
@@ -157,6 +164,7 @@ tar_map2_raw <- function(
         target_downstream,
         values = values,
         names = names,
+        descriptions = descriptions,
         unlist = FALSE
       )
     )
@@ -178,7 +186,8 @@ tar_map2_raw <- function(
       garbage_collection = garbage_collection,
       deployment = "main",
       priority = priority,
-      cue = cue
+      cue = cue,
+      description = description
     )
   )
   unlist(list(target_static, target_combine), recursive = TRUE)
