@@ -84,6 +84,8 @@
 tar_render_raw <- function(
   name,
   path,
+  output_file = NULL,
+  working_directory = NULL,
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   error = targets::tar_option_get("error"),
@@ -92,19 +94,29 @@ tar_render_raw <- function(
   resources = targets::tar_option_get("resources"),
   retrieval = targets::tar_option_get("retrieval"),
   cue = targets::tar_option_get("cue"),
+  description = targets::tar_option_get("description"),
   quiet = TRUE,
   render_arguments = quote(list())
 ) {
   targets::tar_assert_package("rmarkdown")
-  targets::tar_assert_scalar(path)
-  targets::tar_assert_chr(path)
-  targets::tar_assert_path(path)
-  targets::tar_assert_not_dirs(path)
+  targets::tar_assert_file(path)
+  targets::tar_assert_chr(output_file %|||% "x")
+  targets::tar_assert_scalar(output_file %|||% "x")
+  targets::tar_assert_nzchar(output_file %|||% "x")
+  if (!is.null(working_directory)) {
+    targets::tar_assert_file(working_directory)
+  }
   targets::tar_assert_lang(render_arguments)
   targets::tar_assert_not_expr(render_arguments)
   targets::tar_target_raw(
     name = name,
-    command = tar_render_command(path, render_arguments, quiet),
+    command = tar_render_command(
+      path,
+      output_file,
+      working_directory,
+      render_arguments,
+      quiet
+    ),
     packages = packages,
     library = library,
     format = "file",
@@ -114,14 +126,16 @@ tar_render_raw <- function(
     priority = priority,
     resources = resources,
     retrieval = retrieval,
-    cue = cue
+    cue = cue,
+    description = description
   )
 }
 
 
-tar_render_command <- function(path, args, quiet) {
+tar_render_command <- function(path, output, working_directory, args, quiet) {
   args$input <- path
-  args$knit_root_dir <- quote(getwd())
+  args$output_file <- output
+  args$knit_root_dir <- working_directory %|||% quote(getwd())
   args$quiet <- quiet
   deps <- call_list(as_symbols(knitr_deps(path)))
   fun <- call_ns("tarchetypes", "tar_render_run")
